==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>GroupNotify</name>
    <message>
        <location filename="../GroupNotify.qml" line="50"/>
        <source>Clear All</source>
        <translation>Tümünü Temizle</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <location filename="../NotifyHeader.qml" line="20"/>
        <source>Notification Setting</source>
        <translation>Bildirim Ayarı</translation>
    </message>
    <message>
        <location filename="../NotifyHeader.qml" line="56"/>
        <source>Notification Center</source>
        <translation>Bildirim Merkezi</translation>
    </message>
    <message>
        <location filename="../NotifyHeader.qml" line="108"/>
        <source>Clear All</source>
        <translation>Tümünü Temizle</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <location filename="../NotifySetting.qml" line="18"/>
        <source>Unpin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../NotifySetting.qml" line="18"/>
        <source>Pin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../NotifySetting.qml" line="26"/>
        <source>Notification Setting</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <location filename="../notifyitem.cpp" line="76"/>
        <source>Just now</source>
        <translation>Hemen şimdi</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="78"/>
        <source>%1 minutes ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="80"/>
        <source>%1 hours ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="83"/>
        <source>Yesterday </source>
        <translation>Dün</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Tümünü Temizle</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Bildirim Merkezi</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Tümünü Temizle</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Sabitlemeyi kaldır</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Sabitle</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Bildirim Ayarı</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Hemen şimdi</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 dakika önce</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>1 saat önce</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 saat önce</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Dün</translation>
    </message>
</context>
</TS>
